//
// turing - simulation of Turing machines
// Copyright (C) 2009,2010  Joachim Reichel <joachim.reichel@gmx.de>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
//

#include "transition.h"

namespace TM {



Transition::Transition( State state, Character character, State new_state,
        Character new_character, Direction direction)
  : m_state( state),
    m_new_state( new_state),
    m_character ( character),
    m_new_character( new_character),
    m_direction( direction)
{
    TM_ALWAYS_CHECK( is_valid_direction( direction));
}

bool Transition::operator==( const Transition& rhs) const
{
    return ( m_state == rhs.m_state)
        && ( m_character == rhs.m_character)
        && ( m_new_state == rhs.m_new_state)
        && ( m_new_character == rhs.m_new_character)
        && ( m_direction == rhs.m_direction);
}

bool Transition::operator!=( const Transition& rhs) const
{
    return !( *this == rhs);
}

std::ostream& operator<<(std::ostream& stream, const Transition& t)
{
    stream << "(" << t.m_state << ", " << t.m_character << ") => ";
    stream << "(" << t.m_new_state << ", " << t.m_new_character;
    stream  << ", " << t.m_direction << ")";
    return stream;
}



} // namespace TM
